@@ -34,11 +34,12 @@
 /* -------------- general macros ------------- */
 
 #define VERSION              "1.3"      /* version */
-#define REVISION             "2"        /* revison */
-#define VDATE        "Aug 10 1998"      /* version date */
+#define REVISION             "3"        /* revison */
+#define VDATE        "Mar 17 1999"      /* version date */
 #define VERBOSE0           2            /* default verbosity */
 #define DEBUG_LV           0            /* debug output level */
 #define OUTPUTFILE      "Out.ps"        /* standard output file */
+#define INDEXFILE       "Ind.ps"        /* output file for index */
 #define PS_LEVEL           2            /* PS laguage level: must be 1 or 2 */
 
 /* default directory to search for format files */
@@ -126,7 +127,6 @@
 
 #define COMMENT          1      /* types of lines scanned */
 #define MUSIC            2   
-#define TO_BE_CONTINUED  3    
 #define E_O_F            4   
 #define INFO             5
 #define TITLE            6
@@ -438,7 +438,7 @@ struct FORMAT {                        /* struct for page layout */
   int      oneperpage,titlecaps,barnums;
   struct FONTSPEC titlefont,subtitlefont,vocalfont,textfont,tempofont;
   struct FONTSPEC composerfont,partsfont,gchordfont,wordsfont,voicefont;
-  struct FONTSPEC barnumfont,barlabelfont;
+  struct FONTSPEC barnumfont,barlabelfont,indexfont;
 };
 
 struct FORMAT sfmt;                    /* format after initialization */
@@ -475,9 +475,14 @@ int mline;                     /* number music lines in current tune */
 int nsym;                      /* number of symbols in line */
 int nsym0;                     /* nsym at start of parsing a line */
 int pagenum;                   /* current page in output file */
+int writenum;                  /* calls to write_buffer for each one tune */
 int xrefnum;                   /* xref number of current tune */
 int do_meter, do_indent;       /* how to start next block */
 
+int index_pagenum;             /* for index file */
+float index_posx, index_posy;
+int index_initialized;
+
 char gch[201];                   /* guitar chord string */
 int bagpipe;                     /* switch for HP mode */
 int within_tune, within_block;   /* where we are in the file */
@@ -526,6 +531,7 @@ int bars_per_line;                 /* bars for auto linebreaking */
 int continue_lines;                /* flag to continue all lines */
 int landscape;                     /* flag for landscape output */
 int barnums;                       /* interval for bar numbers */
+int make_index;                    /* write index file ? */
 float alfa_c;                      /* max compression allowed */
 float scalefac;                    /* scale factor for symbol size */
 float lmargin;                     /* left margin */
@@ -548,7 +554,7 @@ char infostr[STRL1];             /* title string in PS file */
 
 int  file_open;                  /* for output file */
 int  file_initialized;           /* for output file */
-FILE *fout;                      /* for output file */
+FILE *fout,*findex;              /* for output file */
 int nepsf;                       /* counter for epsf output files */
 
 char sel_str[MAXINF][STRL1];     /* list of selector strings */
@@ -628,11 +634,14 @@ char *argv[];
   bposy=0;
   posx=cfmt.leftmargin;
   posy=cfmt.pageheight-cfmt.topmargin; 
+  writenum=99;
 
   strcpy(page_init, "");
   strcpy (bbb,"");
   for (j=0;j<ninf;j++) {strcat(bbb,in_file[j]); strcat(bbb," ");}
 
+  if ((do_mode == DO_OUTPUT) && make_index) open_index_file (INDEXFILE);
+
   /* ----- start infinite loop for interactive mode ----- */
   for (;;) {
 
@@ -732,6 +741,8 @@ char *argv[];
   
   close_output_file ();
 
+  if ((do_mode == DO_OUTPUT) && make_index) close_index_file ();
+
   exit (0);
 }
 
