@@ -63,6 +63,54 @@ void clear_buffer ()
   ln_num = 0;
 }
 
+/* ----- write_index_entry ------- */
+void write_index_entry ()
+{
+  char s[801];
+  float w,dx1,dx2;
+
+  if (!index_initialized) init_index_file ();
+  
+  if (vb>=8) printf("Write index entry: %5d  <%s>\n",
+                    pagenum, info.title);
+  
+  /* spacing determined here */
+  index_posy = index_posy-1.2*cfmt.indexfont.size;
+
+  if (index_posy-cfmt.indexfont.size < cfmt.botmargin) {
+    close_index_page (findex);
+    init_index_page (findex);
+  }
+
+  dx1 = 1.8*cfmt.indexfont.size;
+  dx2 = dx1+cfmt.indexfont.size;
+  
+  tex_str (info.title,s,&w);
+  if (strlen(s)==0) strcpy (s, "No title");
+  fprintf (findex, "%.2f %.2f M (%d) lshow\n", 
+           index_posx+dx1, index_posy, pagenum);
+
+  fprintf (findex, "%.2f %.2f M (%s) S\n", 
+           index_posx+dx2, index_posy, s);
+
+  if (strlen(info.rhyth) || strlen(info.orig)) {
+    fprintf (findex, "(  (");
+    if (strlen(info.rhyth)) fprintf (findex, "%s", info.rhyth);
+    if (strlen(info.rhyth) && strlen(info.orig))
+      fprintf (findex, ", ");
+    if (strlen(info.orig)) fprintf (findex, "%s", info.orig);
+    fprintf (findex, ")) S\n");
+  }
+
+  
+  if (strlen(info.comp)) fprintf (findex, "(   - %s) S\n", info.comp);
+  
+  if (cfmt.withxrefs) fprintf (findex, "(   [%s]) S\n", info.xref);
+
+}
+
+
+
 
 /* ----- write_buffer: write buffer contents, break at full pages ---- */
 void write_buffer (fp)
@@ -73,6 +121,10 @@ FILE *fp;
   
   if (nbuf==0) return;
 
+  writenum++;
+  
+  if ((writenum==1) && make_index) write_index_entry();
+
   nb=0;
   for (l=0;l<ln_num;l++) {
     b1=0;
