@@ -54,15 +54,17 @@ struct FORMAT *f;
   add_font (&f->subtitlefont);
   add_font (&f->composerfont);
   add_font (&f->partsfont);
+  add_font (&f->tempofont);
   add_font (&f->vocalfont);
   add_font (&f->textfont);
   add_font (&f->wordsfont);
   add_font (&f->gchordfont);
+  add_font (&f->voicefont);
   add_font (&f->barnumfont);
   add_font (&f->barlabelfont);
-  add_font (&f->voicefont);
 }
 
+
 /* ----- set_standard_format ----- */
 void set_standard_format (f)
 struct FORMAT *f;
@@ -116,6 +118,7 @@ struct FORMAT *f;
   fontspec (&f->voicefont,     "Times-Roman",    12.0, 0); 
   fontspec (&f->barnumfont,    "Times-Italic",   12.0, 0); 
   fontspec (&f->barlabelfont,  "Times-Bold",     18.0, 0); 
+  fontspec (&f->indexfont,     "Times-Roman",    11.0, 0); 
   if (vb>=10) printf ("Loading format \"%s\"\n",f->name);
 }
 
@@ -233,6 +236,7 @@ struct FORMAT f;
   print_font("voicefont",    f.voicefont);
   print_font("barnumberfont",f.barnumfont);
   print_font("barlabelfont", f.barlabelfont);
+  print_font("indexfont",    f.indexfont);
 
   printf ("  lineskipfac    %.1f\n",    f.lineskipfac);
   printf ("  parskipfac     %.1f\n",    f.parskipfac);
@@ -264,6 +268,7 @@ float *num;
   sscanf(s,"%f%s", &a, unit);
 
   if      (!strcmp(unit,"cm")) b=a*CM;
+  else if (!strcmp(unit,"mm")) b=a*CM*0.1;
   else if (!strcmp(unit,"in")) b=a*IN;
   else if (!strcmp(unit,"pt")) b=a*PT;
   else {
@@ -420,6 +425,7 @@ struct FORMAT *f;
   else if (!strcmp(w,"voicefont"))     g_fspc(l,nch,&f->voicefont);
   else if (!strcmp(w,"barnumberfont")) g_fspc(l,nch,&f->barnumfont);
   else if (!strcmp(w,"barlabelfont"))  g_fspc(l,nch,&f->barlabelfont);
+  else if (!strcmp(w,"indexfont"))     g_fspc(l,nch,&f->indexfont);
 
   else if (!strcmp(w,"font")) {
     sscanf(l,"%*s %s", fnm);
@@ -438,7 +444,7 @@ struct FORMAT *f;
   }
   
   else {
-    if (vb>=5) printf ("Ignore format line: %s\n", l);
+    if (vb>=5) printf ("Ignore format line:    %s\n", l);
     return 2;
   }
   return 0;
