@@ -271,7 +271,9 @@ struct METERSTR *meter;
 /* ----- set_keysig: interpret keysig string, store in struct ---- */
 /* This part was adapted from abc2mtex by Chris Walshaw */
 /* updated 03 Oct 1997 Wil Macaulay - support all modes */
-void set_keysig(s,ks,init)
+/* Returns 1 if key was actually specified, because then we want
+   to transpose. Returns zero if this is just a clef change. */
+int set_keysig(s,ks,init)
 char s[];
 struct KEYSTR *ks;
 int init;
@@ -292,17 +294,17 @@ int init;
   /* check for "treble" "bass" "alto" with no other information */
   ktype=ks->ktype;
   add_pitch=0;
-  if (!strcmp(s,"bass"))   {ks->ktype=BASS; return; }
-  if (!strcmp(s,"treble")) {ks->ktype=TREBLE; return; }
-  if (!strcmp(s,"alto"))   {ks->ktype=ALTO; return; }
+  if (!strcmp(s,"bass"))   {ks->ktype=BASS;   return 0; }
+  if (!strcmp(s,"treble")) {ks->ktype=TREBLE; return 0; }
+  if (!strcmp(s,"alto"))   {ks->ktype=ALTO;   return 0; }
 
-  if (!strcmp(s,"bass+8"))   {ks->ktype=BASS;   ks->add_pitch=8; return; }
-  if (!strcmp(s,"treble+8")) {ks->ktype=TREBLE; ks->add_pitch=8; return; }
-  if (!strcmp(s,"alto+8"))   {ks->ktype=ALTO;   ks->add_pitch=8; return; }
+  if (!strcmp(s,"bass+8"))   {ks->ktype=BASS;   ks->add_pitch=8; return 0; }
+  if (!strcmp(s,"treble+8")) {ks->ktype=TREBLE; ks->add_pitch=8; return 0; }
+  if (!strcmp(s,"alto+8"))   {ks->ktype=ALTO;   ks->add_pitch=8; return 0; }
 
-  if (!strcmp(s,"bass-8"))   {ks->ktype=BASS;   ks->add_pitch=-8; return; }
-  if (!strcmp(s,"treble-8")) {ks->ktype=TREBLE; ks->add_pitch=-8; return; }
-  if (!strcmp(s,"alto-8"))   {ks->ktype=ALTO;   ks->add_pitch=-8; return; }
+  if (!strcmp(s,"bass-8"))   {ks->ktype=BASS;   ks->add_pitch=-8; return 0; }
+  if (!strcmp(s,"treble-8")) {ks->ktype=TREBLE; ks->add_pitch=-8; return 0; }
+  if (!strcmp(s,"alto-8"))   {ks->ktype=ALTO;   ks->add_pitch=-8; return 0; }
 
   c=0;
   bagpipe=0;
@@ -432,6 +434,8 @@ int init;
   ks->root       = root;
   ks->root_acc   = root_acc;
 
+  return 1;
+
 }
 
 /* ----- get_halftones: figure out how by many halftones to transpose --- */
@@ -529,7 +533,7 @@ int sf_old,nht,*sfnew,*addt;
   sf_new=(sf_new+240)%12;
   if (sf_new>=6) sf_new=sf_new-12;
   
-  /* get old and new root in ioinian mode, shift is difference */
+  /* get old and new root in ionian mode, shift is difference */
   r_old=2;
   if (sf_old>0) r_old=skey_tab[sf_old];
   if (sf_old<0) r_old=fkey_tab[-sf_old];
@@ -567,7 +571,7 @@ struct KEYSTR *key;
   char root_tab[]={'A','B','C','D','E','F','G'};
   char acc_tab[][3] ={"bb","b ","  ","# ","x "};
   char c1[6],c2[6],c3[6];
-  
+
   /* nop if no transposition is wanted */
   if (nht==0) {
     key->add_transp=0;
@@ -1262,6 +1266,7 @@ void handle_inside_field(type)
 int type;
 {
   struct KEYSTR oldkey;
+  int rc;
 
   if (type==METER) {
     if (nvoice==0) ivc=switch_voice (DEFVOICE);
@@ -1277,8 +1282,8 @@ int type;
   else if (type==KEY) {
     if (nvoice==0) ivc=switch_voice (DEFVOICE);
     oldkey=voice[ivc].key;
-    set_keysig(info.key,&voice[ivc].key,0);
-    set_transtab (halftones,&voice[ivc].key);
+    rc=set_keysig(info.key,&voice[ivc].key,0);
+    if (rc) set_transtab (halftones,&voice[ivc].key);
     append_key_change(oldkey,voice[ivc].key);
   }
   
@@ -1637,22 +1642,16 @@ int pgr[],agr[];
   return n;
 }
 
-/* ----- identify_note: set head type, dots, flags for note --- */
-void identify_note (s,q)
+
+/* ----- idfy_note: set head type, dots, flags for one note --- */
+int idfy_note (s)
 struct SYMBOL *s;
-char *q;
 {
   int head,base,len,flags,dots;
 
   if (s->len==0) s->len=s->lens[0];
   len=s->len;
 
-  /* set flag if duration equals length of one measure */
-  if (nvoice>0) {
-    if (len==(WHOLE*voice[ivc].meter.meter1)/voice[ivc].meter.meter2)
-      s->fullmes=1;
-  }
-
   base=WHOLE;
   if (len>=WHOLE)              base=WHOLE;
   else if (len>=HALF)          base=HALF;
@@ -1661,8 +1660,8 @@ char *q;
   else if (len>=SIXTEENTH)     base=SIXTEENTH;
   else if (len>=THIRTYSECOND)  base=THIRTYSECOND;
   else if (len>=SIXTYFOURTH)   base=SIXTYFOURTH;
-  else syntax("Cannot identify head for note",q);
-      
+  else return 1;
+
   if (base==WHOLE)     head=H_OVAL;
   else if (base==HALF) head=H_EMPTY;
   else                 head=H_FULL;
@@ -1678,14 +1677,35 @@ char *q;
   else if (2*len==3*base)   dots=1;
   else if (4*len==7*base)   dots=2;
   else if (8*len==15*base)  dots=3;
-  else syntax("Cannot handle note length for note",q);
+  else return 2;
   
-/*  printf ("identify_note: length %d gives head %d, dots %d, flags %d\n",
-          len,head,dots,flags);  */
+/*|   printf ("idfy_note: length %d gives head %d, dots %d, flags %d\n", |*/
+/*|           len,head,dots,flags);   |*/
 
   s->head=head;
   s->dots=dots;
   s->flags=flags;
+  return 0;
+}
+
+
+
+/* ----- identify_note ----- */
+void identify_note (s,q)
+struct SYMBOL *s;
+char *q;
+{
+  int rc;
+
+  rc = idfy_note (s);
+  if (rc==1) syntax("Cannot identify head for note",q);
+  if (rc==2) syntax("Cannot handle note length for note",q);
+
+  /* set flag if duration equals length of one measure */
+  if (nvoice>0) {
+    if (s->len==(WHOLE*voice[ivc].meter.meter1)/voice[ivc].meter.meter2)
+      s->fullmes=1;
+  }
 }
 
 
@@ -2010,14 +2030,16 @@ char line[];
 int parse_music_line (line)
 char line[];
 {
-  int type,num,nbr,n,itype,i;
+  int type,num,nbr,n,itype,i,nsym00;
   char msg[81];
   char *p1,*pmx;
 
+  if (nvoice==0) ivc=switch_voice (DEFVOICE);
   if (ivc>=nvoice) bug ("Trying to parse undefined voice",1);
 
   nwline=0;                  
   nsym0=voice[ivc].nsym;
+  nsym00=nsym0;
 
   nbr=0;
   p=p0=line;
@@ -2169,7 +2191,11 @@ char line[];
     word=0;
   }
 
-  return TO_BE_CONTINUED;
+  if (vb>9)  
+    printf ("Parsed music symbols %d to %d for voice %d\n", 
+            nsym00,voice[ivc].nsym-1,ivc);
+  
+  return MUSIC;
 
 }
 
@@ -2321,9 +2347,8 @@ char ln[];
 
 
 /* ----- read_line: returns type of line scanned --- */
-int read_line (fp,do_music,line)
+int read_line (fp,line)
 FILE *fp;
-int do_music;
 char line[BSIZE];
 {
   int type,nsym0;
@@ -2350,21 +2375,12 @@ char line[BSIZE];
       return type;
     }
   }
-  
-  if (!do_music) return COMMENT;
-  if (parse_vocals(line)) return MWORDS;
 
-  /* now parse a real line of music */
-  if (nvoice==0) ivc=switch_voice (DEFVOICE);
+  if (do_this_tune) {
+    if (parse_vocals(line)) return MWORDS;
+  }
 
-  nsym0=voice[ivc].nsym;
-  type=parse_music_line (line);
-
-  if (db>1)  
-    printf ("  parsed music symbols %d to %d for voice %d\n", 
-            nsym0,voice[ivc].nsym-1,ivc);
-  
-  return type;
+  return MUSIC;
   
 }
 
