@@ -82,8 +82,6 @@ FILE *fp;
   
 }
 
-
-
 /* ----- init_ps ------- */
 void init_ps (fp,str,is_epsf,bx1,by1,bx2,by2)
 FILE *fp;
@@ -202,6 +200,94 @@ FILE *fp;
   
 }
 
+/* ----- init_index_page ----- */
+void init_index_page (fp)
+FILE *fp;
+{
+  float hsize;
+
+  index_pagenum++;
+
+  fprintf (fp, 
+           "\n%% --- page %d\n"
+           "%%%%Page: %d %d\n"
+           "%%%%BeginPageSetup\n",
+           index_pagenum, index_pagenum, index_pagenum);
+
+  if (cfmt.landscape) fprintf(fp,"%%%%PageOrientation: Landscape\n");
+  if (cfmt.landscape) fprintf(fp,"90 rotate 0 %.1f translate ", 
+                              -cfmt.pageheight);
+  fprintf (findex, "gsave\n"); 
+  fprintf (fp, "%%%%EndPageSetup\n\n");
+  
+  index_posx=cfmt.leftmargin;
+  index_posy=cfmt.pageheight-cfmt.topmargin;
+  /* extra space at top.. */
+
+  index_posy = index_posy - 2*cfmt.indexfont.size;
+
+  /* write heading */
+  if (index_pagenum == 1) {
+    hsize = 1.5*cfmt.indexfont.size;
+    index_posy = index_posy - hsize;
+    fprintf (findex, "%.1f %d F1 \n", hsize,cfmt.indexfont.box);
+    fprintf (findex, "%.2f %.2f M (Contents) S\n", index_posx, index_posy);
+    index_posy = index_posy - cfmt.indexfont.size;
+  }
+
+  fprintf (findex, "%.1f %d F1 \n", 
+           cfmt.indexfont.size, cfmt.indexfont.box);
+
+}
+
+
+
+/* ----- init_index_file ------- */
+void init_index_file ()
+{
+  time_t  ltime;
+  char    tstr[41];
+  
+  fprintf (findex, "%%!PS-Adobe-3.0\n");
+  fprintf (findex, "%%%%Title: abc2ps index\n");
+  time(&ltime);              
+  strcpy (tstr,  ctime(&ltime));
+  tstr[24]='\0';
+  tstr[16]='\0';
+  fprintf (findex, "%%%%Creator: abc2ps %s.%s\n", VERSION, REVISION);
+  fprintf (findex, "%%%%CreationDate: %s %s\n", tstr+4,tstr+20);
+  if (PS_LEVEL == 2) fprintf (findex, "%%%%LanguageLevel: 2\n");
+  fprintf (findex, "%%%%EndComments\n\n");
+
+  fprintf (findex, "%%%%BeginSetup\n");
+  if (PS_LEVEL < 2) level1_fix (findex);
+
+  define_font (findex,cfmt.indexfont.name,1);
+  fprintf (findex, "\n/T {translate} bind def\n/M {moveto} bind def\n");
+  fprintf (findex, "/S {show} bind def\n");
+  def_misc (findex);
+  fprintf (findex, "%%%%EndSetup\n\n");
+  
+  index_pagenum=0;
+  init_index_page (findex);
+  
+  index_initialized=1;
+
+}
+
+
+/* ----- close_index_page-------- */
+void close_index_page (fp)
+FILE *fp;
+{
+
+  fprintf (fp, 
+           "\n%%%%PageTrailer\n"
+           "grestore\n"
+           "showpage\n");
+}
+
+
 /* ----- close_page-------- */
 void close_page (fp)
 FILE *fp;
@@ -249,3 +335,4 @@ FILE *fp;
   posy=cfmt.pageheight-cfmt.topmargin;
   
 }
+
