@@ -46,6 +46,7 @@ void write_help ()
           "       -k nn   number every nn bars; 0 for first in staff\n"
           "       -n      include notes and history in output\n"
           "       -N      write page numbers\n"
+          "       -I      write index to Ind.ps\n"
           "       -1      write one tune per page\n"
           "       -l      landscape mode\n"
           "       -g xx   set glue mode to shrink|space|stretch|fill\n"
@@ -141,6 +142,7 @@ int job;
   strict1              = -1.0;
   strict2              = -1.0;
   barnums              = -1;
+  make_index           =  0;
 
   select_all           = 0;
   do_mode              = DO_INDEX;
@@ -276,6 +278,7 @@ char *av[];
           else if (c=='E')  epsf=1;
           else if (c=='o')  do_mode=DO_OUTPUT;
           else if (c=='N')  pagenumbers=1;
+          else if (c=='I')  make_index=1;
           else if (strchr("TCRS",c)) {           
             if (c=='T') s_field[nsel]=S_TITLE; 
             if (c=='C') s_field[nsel]=S_COMPOSER;
@@ -764,6 +767,31 @@ char fnam[],tstr[];
 }
 
 
+
+/* ----- open_index_file ------- */
+void open_index_file (fnam)
+char fnam[];
+{
+  if (vb>=8) printf("Open index file \"%s\"\n", fnam);
+  if ((findex = fopen (fnam,"w")) == NULL) 
+    rx ("Cannot open index file: ", fnam);
+
+  index_initialized=0;
+  
+}
+
+/* ----- close_index_file ------- */
+void close_index_file ()
+{
+  
+  if (vb>=8) printf("Close index file\n");
+
+  close_index_page (findex);
+
+  fclose (findex);
+
+}
+
 /* ----- add_to_text_block ----- */
 void add_to_text_block (ln,add_final_nl)
 char ln[];
@@ -1110,12 +1138,13 @@ struct METERSTR meter;
 {
   char *r, *q;
   char text[STRL];
-  int top,bot,value,len,i,err,fac,dig,div;
+  int top,bot,value,len,i,err,fac,dig,div,rc;
   struct SYMBOL s;
   float stem,dotx,doty,sc,dx;
 
   if (vb>15) printf ("write tempo <%s>\n", info.tempo);
   r=tempo;
+  p0=tempo;
   set_font (fp,cfmt.tempofont,0);
   PUT0(" 18 0 M\n")
 
@@ -1141,14 +1170,15 @@ struct METERSTR meter;
       q=text;
       while (*r!=' ' && *r!='\0') { *q=*r; r++; q++; }
       *q='\0';
-      
       q=text;
+
       len=QUARTER;
       value=0;
       err=0;
       if (strchr(q,'=')) {
-        if (*q=='C' || *q=='c') {
+        if ((*q=='C') || (*q=='c')) {
           q++;
+
           len=meter.dlen;  
           div=0;
           if (*q=='/') { div=1; q++; }
@@ -1179,11 +1209,12 @@ struct METERSTR meter;
         else err=1;
       }
       
+      s.len=len;
+      rc = idfy_note (&s);
+      if (rc) err=1;
       if (err)                              /* draw note=value */
         printf("\n+++ invalid tempo specifier: %s\n", text);
       else {
-        s.len=len;
-        identify_note (&s,r);
         sc=0.55*cfmt.tempofont.size/10.0;
         PUT2("gsave %.2f %.2f scale 15 3 rmoveto currentpoint\n", sc,sc)
         if (s.head==H_OVAL)  PUT0("HD")
@@ -1220,7 +1251,7 @@ FILE *fp;
 {
 
   bskip (cfmt.partsfont.size);
-  write_tempo(fp,info.tempo,voice[ivc].meter);
+  write_tempo(fp,info.tempo,default_meter);
   bskip (0.1*CM);
 }
 
@@ -1338,3 +1369,4 @@ FILE *fp;
   }
 }   
 
+
