@@ -1,5 +1,6 @@
 /*  
- *  This file is part of abc2ps, Copyright (C) 1996,1997 Michael Methfessel
+ *  This file is part of abc2ps, 
+ *  Copyright (C) 1996,1997,1998  Michael Methfessel
  *  See file abc2ps.c for details.
  */
  
@@ -12,16 +13,26 @@ FILE *fp;
   fprintf (fp,
            "\n/cshow { %% usage: string cshow  - center at current pt\n"
            "   dup stringwidth pop 2 div neg 0 rmoveto\n"
-           "   currentpoint pop dup 0 lt {neg 0 rmoveto} {pop} ifelse\n"
-           "   show\n"
+           "   bx {box} if show\n"
            "} bind def\n"
            "\n/lshow { %% usage: string lshow - show left-aligned\n"
-           "   dup stringwidth pop neg 0 rmoveto show\n"
+           "   dup stringwidth pop neg 0 rmoveto bx {box} if show\n"
+           "} bind def\n"
+           "\n/rshow { %% usage: string rshow - show right-aligned\n"
+           "   bx {box} if show\n"
            "} bind def\n"
            );
+  
+  fprintf (fp,
+           "\n/box {  %% usage: str box  - draw box around string\n"
+           "  gsave 0.5 setlinewidth dup stringwidth pop\n"
+           "  -2 -2 rmoveto 4 add fh 4 add 2 copy\n"
+           "  0 exch rlineto 0 rlineto neg 0 exch rlineto neg 0 rlineto\n"
+           "  stroke grestore\n"
+           "} bind def\n");
 
   fprintf (fp, 
-           "\n/wd { moveto show } bind def\n"
+           "\n/wd { moveto bx {box} if show } bind def\n"
            "/wln {\n"
            "dup 3 1 roll moveto gsave 0.6 setlinewidth lineto stroke grestore\n"
            "} bind def\n");
@@ -31,7 +42,6 @@ FILE *fp;
 
 }
 
-
 /* ----- def_typset ------- */
 void def_typeset(fp)
 FILE *fp;
@@ -94,10 +104,13 @@ int  num;
 
   if (!strcmp(name,"Symbol")) {
     fprintf (fp, 
-             "/F%d { /%s exch selectfont } bind def\n", 
+             "/F%d { 1 eq {/bx true def} { /bx false def} ifelse\n"
+             "  dup 0.72 mul  /fh exch def\n"
+             "  /%s exch selectfont } bind def\n", 
              num, name); 
     return;
   }
+
   fprintf (fp,
            "\n/%s findfont\n"
            "dup length dict begin\n"
@@ -109,7 +122,9 @@ int  num;
            name, name);
   
    fprintf (fp, 
-            "/F%d { /%s-ISO exch selectfont } bind def\n", 
+            "/F%d { 1 eq {/bx true def} { /bx false def} ifelse\n"
+            "  dup 0.72 mul  /fh exch def\n"
+            "  /%s-ISO exch selectfont } bind def\n", 
             num, name); 
 
 }
@@ -121,7 +136,7 @@ FILE *fp;
 {
   fprintf (fp,
            "\n/tsig { %% usage: x (top) (bot) tsig -- draw time signature\n"
-           "   3 -1 roll 0 moveto\n"
+           "   3 -1 roll 0 moveto /bx false def\n"
            "   gsave /Times-Bold 16 selectfont 1.2 1 scale\n"
            "   0 1.0 rmoveto currentpoint 3 -1 roll cshow\n"
            "   moveto 0 12 rmoveto cshow grestore\n"
@@ -240,6 +255,17 @@ FILE *fp;
   fprintf (fp, "\n/stc {  %% usage:  y stc  - staccato mark\n"
            "  x exch 1.2 0 360 arc fill } bind def\n");
 
+  fprintf (fp, "\n/hat {  %% usage:  y hat\n"
+           "  x exch moveto\n"
+           "  -4 -2 rmoveto 4 6 rlineto currentpoint stroke moveto\n"
+           "  4 -6 rlineto -2 0 rlineto -3 4.5 rlineto fill\n"
+           " } bind def\n");
+
+  fprintf (fp, "\n/att {  %% usage:  y att\n"
+           "  x exch moveto\n"
+           "  -4 -3 rmoveto 8 3 rlineto -8 3 rlineto stroke\n"
+           " } bind def\n");
+
   f2=f2*1.8;
 
   if (temp_switch==3) { f1=0.8*f1; f2=0.8*f2; }
@@ -268,8 +294,8 @@ FILE *fp;
   fprintf (fp, "   fill\n} bind def\n");
   
   fprintf (fp, "\n/emb {  %% usage:  y emb  - empahsis bar\n"
-           "  gsave 1.2 setlinewidth 1 setlinecap x exch moveto \n"
-           " -2.5 0 rmoveto 5 0 rlineto stroke grestore\n"
+           "  gsave 1.4 setlinewidth 1 setlinecap x exch moveto \n"
+           " -3.5 0 rmoveto 7 0 rlineto stroke grestore\n"
            "} bind def\n");
 
   fprintf (fp, "\n/trl {  %% usage:  y trl  - trill sign\n"
@@ -356,7 +382,7 @@ FILE *fp;
   fprintf(fp, 
           "\n/bnum {  %% usage: x y (str) bnum  - number on beam\n"
           "  3 1 roll moveto gsave /Times-Italic 12 selectfont\n"
-          "  cshow grestore\n"
+          "  /bx false def cshow grestore\n"
           "} bind def\n");
   
 
@@ -488,6 +514,13 @@ FILE *fp;
     {-2.5,2}, {2.5,3}, {2.5,6}, {-2.5,5}, {-2.5,2},
     {-2.5,11}, {-2.5,-5.5},  
     {2.5,5.5}, {2.5,-11} };
+  float s[25][2]={
+    {0.7,0},{3.9,3},{6,3},{6.2,6.2},{3,6},{3,3.9},
+    {0,0.7},{-3,3.9},{-3,6},{-6.2,6.2},{-6,3},{-3.9,3},
+    {-0.7,0},{-3.9,-3},{-6,-3},{-6.2,-6.2},{-3,-6},{-3,-3.9},
+    {0,-0.7},{3,-3.9},{3,-6},{6.2,-6.2},{6,-3},{3.9,-3},
+    {0.7,0} };
+
 
   float f1,f2;
   
@@ -503,6 +536,23 @@ FILE *fp;
   fprintf (fp, "  stroke\n } bind def\n");
   fprintf (fp, "/ft { %% usage: dx ft  - flat relative to head\n"
            " neg x add y ft0 } bind def\n");
+  
+  f2=8.0/9.0;    /* more narrow flat sign for double flat */
+  f1=f2*0.8;
+  fprintf (fp, "\n/ftx { %% usage:  x y ftx  - narrow flat sign\n"
+           "  moveto\n"); 
+  add_mv (fp,f1,f2,p,0);
+  add_cv (fp,f1,f2,p,1,2);
+  fprintf (fp, "  currentpoint fill moveto\n");
+  add_mv (fp,f1,f2,p,7);
+  add_sg (fp,f1,f2,p,8,1);
+  fprintf (fp, "  stroke\n } bind def\n");
+
+  fprintf (fp, "/dft0 { %% usage: x y dft0 ft  - double flat sign\n"
+           "  2 copy exch 2.5 sub exch ftx exch 1.5 add exch ftx } bind def\n"
+           "/dft { %% usage: dx dft  - double flat relative to head\n"
+           "  neg x add y dft0 } bind def\n");
+
 
   f2=6.5/9.0;
   f1=f2*0.9;
@@ -540,6 +590,15 @@ FILE *fp;
   fprintf (fp, "/nt { %% usage: dx nt  - neutral relative to head\n"
            " neg x add y nt0 } bind def\n");
 
+  f1=5.0/9.0;
+  f2=f1;
+  fprintf (fp, "\n/dsh0 {  %% usage:  x y dsh0  - double sharp \n"
+           "  moveto\n"); 
+  add_mv (fp,f1,f2,s,0);
+  add_sg (fp,f1,f2,s,1,24);
+  fprintf (fp, "  fill\n } bind def\n");
+  fprintf (fp, "/dsh { %% usage: dx dsh  - double sharp relative to head\n"
+           " neg x add y dsh0 } bind def\n");
 }
 
 /* ----- def_rests ------- */
@@ -594,17 +653,20 @@ FILE *fp;
   add_sg (fp,f1,f2,r,26,3);
   fprintf (fp, "  fill\n } bind def\n");
 
+  
   fprintf (fp, 
-           "\n/r1 {  %% usage:  x y r2  -  half rest\n"
+           "\n/r1 {  %% usage:  x y r1  -  whole rest\n"
            "  dup /y exch def exch dup /x exch def exch moveto\n"
-           "  -3 0 rmoveto 0 -3 rlineto 6 0 rlineto 0 3 rlineto fill\n"
-           "} bind def\n"
+           "  -3 6 rmoveto 0 -3 rlineto 6 0 rlineto 0 3 rlineto fill\n"
+           "} bind def\n");
+
+  fprintf (fp, 
            "\n/r2 {  %% usage:  x y r2  -  half rest\n"
            "  dup /y exch def exch dup /x exch def exch moveto\n"
            "  -3 0 rmoveto 0 3 rlineto 6 0 rlineto 0 -3 rlineto fill\n"
            "} bind def\n"
            );
-
+  
   /* get 32nd, 64th rest by overwriting 8th and 16th rests */
   fprintf (fp,
            "\n/r32 {\n"
@@ -655,6 +717,7 @@ FILE *fp;
 void def_ends (fp)
 FILE *fp;
 {
+  /* use dy=20 for tall boxes */
   int y=50,dy=6;
 
   fprintf(fp, "\n/end1 {  %% usage: x1 x2 (str) end1  - mark first ending\n"
@@ -677,7 +740,7 @@ void def_gchord (fp)
 FILE *fp;
 {
   fprintf(fp,"\n/gc { %% usage: x y (str) gc  -- draw guitar chord string\n"
-          "  3 1 roll moveto show\n"
+          "  3 1 roll moveto rshow\n"
           "} bind def\n");
 }
 
@@ -884,6 +947,14 @@ FILE *fp;
   fprintf(fp, "\n/gnt0 {  %% usage: x y gnt0\n"
           "gsave translate 0.7 0.7 scale 0 0 nt0 grestore\n"
           "} bind def\n");
+
+  fprintf(fp, "\n/gdf0 {  %% usage: x y gdf0\n"
+          "gsave translate 0.7 0.6 scale 0 0 dft0 grestore\n"
+          "} bind def\n");
+
+  fprintf(fp, "\n/gds0 {  %% usage: x y gds0\n"
+          "gsave translate 0.7 0.7 scale 0 0 dsh0 grestore\n"
+          "} bind def\n");
 }
 
 
@@ -1041,6 +1112,54 @@ FILE *fp;
   fprintf (fp, "\n/scclef { cclef } bind def\n");
 }
 
+/* ----- def_brace ------- */
+void def_brace (fp)
+FILE *fp;
+{
+  float p[8][2]={
+    {7.2,60}, {-7,39}, {17,17}, {-1,0}, 
+    {-1.4,0}, {13,13}, {-11,39}, {7,60} };
+
+  float q[8][2]={
+    {-3,0}, {2,0}, {4,1}, {5.5,5}, 
+    {5.9,4.7}, {4.7,1.2}, {3.2,-.4}, {-1,-1.2} };
+
+  float f1,f2;
+
+  f1 = 0.9;
+  f2 = 1.0;
+  fprintf (fp, "\n/bracehalf {\n");
+  add_mv (fp,f1,f2,p,0);
+  add_cv (fp,f1,f2,p,1,1);
+  add_sg (fp,f1,f2,p,4,1);
+  add_cv (fp,f1,f2,p,5,1);
+  fprintf (fp, "  fill\n} bind def\n");
+
+  fprintf (fp,
+           "\n/brace {   %% usage: scale x0 y0 brace\n"
+           "   3 copy moveto gsave 1 exch scale bracehalf grestore\n"
+           "   moveto gsave neg 1 exch scale bracehalf grestore\n"
+           "} bind def\n");
+
+  f1 = 1.0;
+  f2 = 1.0;
+  fprintf (fp, "\n/brackhead {\n");
+  add_mv (fp,f1,f2,q,0);
+  add_cv (fp,f1,f2,q,1,1);
+  add_sg (fp,f1,f2,q,4,1);
+  add_cv (fp,f1,f2,q,5,1);
+  fprintf (fp, "  fill\n} bind def\n");
+
+  fprintf (fp,
+           "\n/bracket {   %% usage: h x0 y0 bracket\n"
+           "   3 copy moveto 0 exch rmoveto brackhead\n"
+           "   3 copy moveto pop gsave 1 -1 scale brackhead grestore \n"
+           "   moveto -3 0 rlineto 0 exch rlineto 3 0 rlineto fill\n"
+           "} bind def \n");
+
+}
+
+
 /* ----- def_staff ------- */
 void def_staff (fp)
 FILE *fp;
@@ -1099,6 +1218,7 @@ FILE *fp;
   def_sep (fp);
   def_tsig (fp);
   def_staff (fp);
+  def_brace (fp);
   def_typeset(fp);
 
 }
